#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'history-dock-widget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/pub/devel/octave/octave-6.4.0-1.i686/src/octave-6.4.0/libgui/src/history-dock-widget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'history-dock-widget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__history_dock_widget_t {
    QByteArrayData data[33];
    char stringdata0[487];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__history_dock_widget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__history_dock_widget_t qt_meta_stringdata_octave__history_dock_widget = {
    {
QT_MOC_LITERAL(0, 0, 27), // "octave::history_dock_widget"
QT_MOC_LITERAL(1, 28, 11), // "information"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 7), // "message"
QT_MOC_LITERAL(4, 49, 22), // "command_double_clicked"
QT_MOC_LITERAL(5, 72, 7), // "command"
QT_MOC_LITERAL(6, 80, 21), // "command_create_script"
QT_MOC_LITERAL(7, 102, 8), // "commands"
QT_MOC_LITERAL(8, 111, 11), // "set_history"
QT_MOC_LITERAL(9, 123, 4), // "hist"
QT_MOC_LITERAL(10, 128, 14), // "append_history"
QT_MOC_LITERAL(11, 143, 10), // "hist_entry"
QT_MOC_LITERAL(12, 154, 13), // "clear_history"
QT_MOC_LITERAL(13, 168, 13), // "save_settings"
QT_MOC_LITERAL(14, 182, 15), // "notice_settings"
QT_MOC_LITERAL(15, 198, 19), // "const gui_settings*"
QT_MOC_LITERAL(16, 218, 21), // "update_filter_history"
QT_MOC_LITERAL(17, 240, 15), // "filter_activate"
QT_MOC_LITERAL(18, 256, 6), // "enable"
QT_MOC_LITERAL(19, 263, 7), // "ctxMenu"
QT_MOC_LITERAL(20, 271, 3), // "pos"
QT_MOC_LITERAL(21, 275, 19), // "handle_double_click"
QT_MOC_LITERAL(22, 295, 10), // "modelIndex"
QT_MOC_LITERAL(23, 306, 23), // "handle_contextmenu_copy"
QT_MOC_LITERAL(24, 330, 4), // "flag"
QT_MOC_LITERAL(25, 335, 27), // "handle_contextmenu_evaluate"
QT_MOC_LITERAL(26, 363, 32), // "handle_contextmenu_create_script"
QT_MOC_LITERAL(27, 396, 25), // "handle_contextmenu_filter"
QT_MOC_LITERAL(28, 422, 13), // "copyClipboard"
QT_MOC_LITERAL(29, 436, 14), // "pasteClipboard"
QT_MOC_LITERAL(30, 451, 9), // "selectAll"
QT_MOC_LITERAL(31, 461, 17), // "handle_visibility"
QT_MOC_LITERAL(32, 479, 7) // "visible"

    },
    "octave::history_dock_widget\0information\0"
    "\0message\0command_double_clicked\0command\0"
    "command_create_script\0commands\0"
    "set_history\0hist\0append_history\0"
    "hist_entry\0clear_history\0save_settings\0"
    "notice_settings\0const gui_settings*\0"
    "update_filter_history\0filter_activate\0"
    "enable\0ctxMenu\0pos\0handle_double_click\0"
    "modelIndex\0handle_contextmenu_copy\0"
    "flag\0handle_contextmenu_evaluate\0"
    "handle_contextmenu_create_script\0"
    "handle_contextmenu_filter\0copyClipboard\0"
    "pasteClipboard\0selectAll\0handle_visibility\0"
    "visible"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__history_dock_widget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  114,    2, 0x06 /* Public */,
       4,    1,  117,    2, 0x06 /* Public */,
       6,    1,  120,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,  123,    2, 0x0a /* Public */,
      10,    1,  126,    2, 0x0a /* Public */,
      12,    0,  129,    2, 0x0a /* Public */,
      13,    0,  130,    2, 0x0a /* Public */,
      14,    1,  131,    2, 0x0a /* Public */,
      16,    0,  134,    2, 0x08 /* Private */,
      17,    1,  135,    2, 0x08 /* Private */,
      19,    1,  138,    2, 0x08 /* Private */,
      21,    1,  141,    2, 0x08 /* Private */,
      23,    1,  144,    2, 0x08 /* Private */,
      25,    1,  147,    2, 0x08 /* Private */,
      26,    1,  150,    2, 0x08 /* Private */,
      27,    0,  153,    2, 0x08 /* Private */,
      28,    0,  154,    2, 0x08 /* Private */,
      29,    0,  155,    2, 0x08 /* Private */,
      30,    0,  156,    2, 0x08 /* Private */,
      31,    1,  157,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    7,

 // slots: parameters
    QMetaType::Void, QMetaType::QStringList,    9,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void, QMetaType::QPoint,   20,
    QMetaType::Void, QMetaType::QModelIndex,   22,
    QMetaType::Void, QMetaType::Bool,   24,
    QMetaType::Void, QMetaType::Bool,   24,
    QMetaType::Void, QMetaType::Bool,   24,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   32,

       0        // eod
};

void octave::history_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        history_dock_widget *_t = static_cast<history_dock_widget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->information((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->command_double_clicked((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->command_create_script((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->set_history((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 4: _t->append_history((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->clear_history(); break;
        case 6: _t->save_settings(); break;
        case 7: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
        case 8: _t->update_filter_history(); break;
        case 9: _t->filter_activate((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->ctxMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 11: _t->handle_double_click((*reinterpret_cast< QModelIndex(*)>(_a[1]))); break;
        case 12: _t->handle_contextmenu_copy((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->handle_contextmenu_evaluate((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->handle_contextmenu_create_script((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->handle_contextmenu_filter(); break;
        case 16: _t->copyClipboard(); break;
        case 17: _t->pasteClipboard(); break;
        case 18: _t->selectAll(); break;
        case 19: _t->handle_visibility((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (history_dock_widget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&history_dock_widget::information)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (history_dock_widget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&history_dock_widget::command_double_clicked)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (history_dock_widget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&history_dock_widget::command_create_script)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject octave::history_dock_widget::staticMetaObject = {
    { &octave_dock_widget::staticMetaObject, qt_meta_stringdata_octave__history_dock_widget.data,
      qt_meta_data_octave__history_dock_widget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::history_dock_widget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::history_dock_widget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__history_dock_widget.stringdata0))
        return static_cast<void*>(this);
    return octave_dock_widget::qt_metacast(_clname);
}

int octave::history_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = octave_dock_widget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void octave::history_dock_widget::information(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void octave::history_dock_widget::command_double_clicked(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void octave::history_dock_widget::command_create_script(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
